@@ -19,6 +19,8 @@
  * USA.
  */
 
+#include <config.h>
+
 #include <sys/file.h>
 #include <sys/stat.h>
 #include <gnome.h>
@@ -27,7 +29,6 @@
 
 #include "acme.h"
 #include "eggcellrendererkeys.h"
-#include "config.h"
 
 #define BACKSPACE_KEYCODE 22
 #define C_KEYCODE 54
@@ -97,7 +98,7 @@ keys_edited_callback (GtkCellRendererText *cell, const char *path_string,
 	GtkTreeModel *model = (GtkTreeModel *)data;
 	GtkTreePath *path = gtk_tree_path_new_from_string (path_string);
 	GtkTreeIter iter;
-	char *gconf_path;
+	char *gconf_path, *value_str;
 	int value;
 
 	gtk_tree_model_get_iter (model, &iter, path);
@@ -113,12 +114,16 @@ keys_edited_callback (GtkCellRendererText *cell, const char *path_string,
 	}
 
 	if (keycode == BACKSPACE_KEYCODE)
-		value = -1;
-	else
+	{
+		value = 0;
+		value_str = g_strdup (_("Disabled"));
+	} else {
 		value = keycode;
+		value_str = g_strdup_printf ("%d", value);
+	}
 
 	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-			KEYVAL_COL, value,
+			KEYVAL_COL, value_str,
 			-1);
 	gconf_client_set_int (conf_client,
 			gconf_path, value, NULL);
@@ -131,12 +136,18 @@ init_content_helper (GtkListStore *store, const char *path,
 		const char *desc, int keyval)
 {
 	GtkTreeIter iter;
+	char *keyval_str;
+
+	if (keyval > 0)
+		keyval_str = g_strdup_printf ("%d", keyval);
+	else
+		keyval_str = g_strdup (_("Disabled"));
 
 	gtk_list_store_append (store, &iter);
 	gtk_list_store_set (store, &iter,
 			PATH_COL, path,
 			DESC_COL, desc,
-			KEYVAL_COL, keyval,
+			KEYVAL_COL, keyval_str,
 			-1);
 }
 
@@ -198,7 +209,7 @@ init_treeview (GtkWidget *treeview)
 	model = GTK_TREE_MODEL (gtk_list_store_new (NUM_COLS,
 				G_TYPE_STRING,
 				G_TYPE_STRING,
-				G_TYPE_INT));
+				G_TYPE_STRING));
 
 	/* the treeview */
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), model);
@@ -255,6 +266,10 @@ main (int argc, char *argv[])
 {
 	GtkWidget *dialog;
 
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
+
 	gnome_program_init ("acme-properties", VERSION,
 			LIBGNOMEUI_MODULE,
 			argc, argv,
